
-- return the window size
function getWindowSize()
	return 770, 315
end

-- return the main font
-- the return is a list of font filename and size options
-- the first one found will be used
function getFont()
	if isMac then
		return { { name="Verdana.ttf", size=13 }, { name="Monaco.dfont", size=13 } }
	else
		return { { name="Verdana.ttf", size=13 }, { name="arial.ttf", size=13 } }
	end
end
-- return the label font
function getLabelFont()
	if isMac then
		return { { name="Verdana.ttf", size=11 }, { name="Monaco.dfont", size=11 } }
	else
		return { { name="Verdana.ttf", size=11 }, { name="arial.ttf", size=11 } }
	end
end
-- return the text field font
function getTextFieldFont()
	if isMac then
		return { { name="Verdana.ttf", size=11 }, { name="Monaco.dfont", size=11 } }
	else
		return { { name="Verdana.ttf", size=11 }, { name="arial.ttf", size=11 } }
	end
end

-- create and lay out all the controls
function createUI()

	-- constants
	local windowEdgePad = 5.0
	local kKnobSize = 30
	local kKnobSpace = 53
	local kTextFieldH = 12
	local kZeroButtonWidth = 50
	local pad = 10.0
	local ww, wh = getWindowSize()

	-- make renderers
	theKnobRenderer = knobRenderer()

	-- set window background colour
	setBackgroundColour( 0.2, 0.2, 0.0 )

	-- set location of the banner
	setBannerPosition( 290.0 )

	-- set outline colours for groups
	setGroupActiveColour( 0.5, 0.6, 0.7, 0.6 )
	setGroupInactiveColour( 0.4, 0.4, 0.6, 0.5 )
	
	local function knobAndTextField( group, param, labelText, x, y, w )
		local w = w or kKnobSize
		local size = kKnobSize
		local knobx = x + 0.5 * ( kKnobSize - size ) + 0.5 * ( w - kKnobSize )
		group:add( knob( param, knobx, y+0+1, size ) )
--		group:add( knob( param, knobx, y+kTextFieldH+1, size ) )
--		local tex = textField( param, x, y, w, kTextFieldH )
--		group:add( tex )
		local lab = label( labelText, x+0.5*w, y-3 )
		lab:setBackgroundColour( 0.1, 0.1, 0.15, 0.3 )
		lab:setForegroundColour( 0.9, 0.9, 0.9, 1.0 )
		group:add( lab )
	end

	-- make groups and knobs
	--

	local x = windowEdgePad
	local ybase = windowEdgePad
	local y = ybase

	delayGroup = group( "Delay" )
	knobAndTextField( delayGroup, "Delay Time", "Time", 	0*kKnobSpace, 0 )
	knobAndTextField( delayGroup, "Feedback", 	"Feedback", 1*kKnobSpace, 0 )
	delayGroup:setPosition( x, y, true )
	y = y + delayGroup:height() + pad

	mixGroup = group( "Mix" )
	knobAndTextField( mixGroup, "Dry Level", 	"Dry", 		0*kKnobSpace, 0 )
	knobAndTextField( mixGroup, "Effect Level", "Effect",	1*kKnobSpace, 0 )
	mixGroup:setPosition( x, y, true )

	x = x + delayGroup:width() + pad
	y = ybase

	filterGroup = group( "Filter" )
	knobAndTextField( filterGroup, "Filter Cutoff", 	"Cutoff", 		0*kKnobSpace, 0 )
	knobAndTextField( filterGroup, "Filter Q", 			"Resonance", 	1*kKnobSpace, 0 )
	knobAndTextField( filterGroup, "Filter Type", 		"Type", 		2*kKnobSpace, 0 )
	knobAndTextField( filterGroup, "Saturation Amount", "Saturation", 	3*kKnobSpace, 0 )
	knobAndTextField( filterGroup, "Saturation Shape", 	"Shape", 		4*kKnobSpace, 0 )
	filterGroup:setPosition( x, y, true )
	x = x + filterGroup:width() + pad

	syncGroup = group( "Sync" )
	knobAndTextField( syncGroup, "Host Tempo", 		"Host Sync", 	0*kKnobSpace, 0 )
	knobAndTextField( syncGroup, "Beats", 			"Beats", 		1*kKnobSpace, 0 )
	knobAndTextField( syncGroup, "Beat Divisor", 	"Divisor", 		2*kKnobSpace, 0 )
	knobAndTextField( syncGroup, "Triplet", 		"Triplet", 		3*kKnobSpace, 0 )
	syncGroup:add( phaseDisc( 0,							4*kKnobSpace, 0, kKnobSize, kKnobSize ) )
	syncGroup:add( button( "Re-Sync", 		"Zero", 		5*kKnobSpace, 0, kZeroButtonWidth, kKnobSize ) )
	syncGroup:setPosition( x, y, true )
	y = y + syncGroup:height() + pad

	lfoSyncGroup = group( "LFO Sync" )
	knobAndTextField( lfoSyncGroup, "LFO Host Tempo", 	"Host Sync", 	0*kKnobSpace, 0 )
	knobAndTextField( lfoSyncGroup, "LFO Beats", 		"Beats", 		1*kKnobSpace, 0 )
	knobAndTextField( lfoSyncGroup, "LFO Beat Divisor", "Divisor", 		2*kKnobSpace, 0 )
	knobAndTextField( lfoSyncGroup, "LFO Triplet", 		"Triplet", 		3*kKnobSpace, 0 )
	lfoSyncGroup:add( phaseDisc( 1,								4*kKnobSpace, 0, kKnobSize, kKnobSize ) )
	lfoSyncGroup:add( button( "LFO Re-Sync", 	"Zero", 		5*kKnobSpace, 0, kZeroButtonWidth, kKnobSize ) )
	lfoSyncGroup:setPosition( x, y, true )

	lfoGroup = group( "LFO" )
	knobAndTextField( lfoGroup, "Filter LFO Speed", 	"Speed", 	0*kKnobSpace, 0 )
	knobAndTextField( lfoGroup, "Filter LFO Amount", 	"Amount",	1*kKnobSpace, 0 )
	x = x - lfoGroup:width() - pad
	lfoGroup:setPosition( x, y, true )
	y = y + lfoGroup:height() + 2*pad

--	oscGroup = group( "OSC" )
--	knobAndTextField( oscGroup, "OSC Port Offset",		"Port",		0*kKnobSpace, 0 )
--	x = x - oscGroup:width() - pad
--	oscGroup:setPosition( x, y, true )
--	oscGroup:setVisible( false )
--	y = y + oscGroup:height() + pad

	local ww, wh = getWindowSize()
	local prefsW = kKnobSize+20
	local prefsH = 25
	local prefsX = ww-prefsW-windowEdgePad

	-- set location of the banner
	setBannerBounds( pad, wh - 25, prefsX - pad, wh - 10 )
	setBannerContent( "full", 60, -1 )

	-- add the prefs button
	add( button( "Prefs", "Prefs", prefsX, wh-prefsH-windowEdgePad, prefsW, prefsH ) )

	-- add the waveform display
	waveformGroup = group( "Meringue" )
	waveformGroup:add( waveformDisplay( 20.0, y, ww - 2*20.0, 100.0 ) )
	waveformGroup:add( kitt( 20.0, y, ww - 2*20.0, 100.0 ) )

end		-- of createUI()
